@@ -6,7 +6,6 @@ import os
 def uncompress(zip_file_path, password):
     password_bytes = password.encode('utf-8')
     unzip_file_name = zip_file_path.split(os.sep)[-1].split(".zip")[0]
-    unzip_folder_name = "GPS_unzipped"
     zip_folder_path = os.path.abspath(os.path.join(zip_file_path, os.pardir))
     with pyzipper.AESZipFile(zip_file_path) as zf:
         zf.extractall(path=zip_folder_path, pwd=password_bytes)
@@ -18,7 +17,7 @@ def uncompress(zip_file_path, password):
 
 
 def delete_unzipped_file(unzip_file_path):
-    os.remove(unzip_file_path)
+    # os.remove(unzip_file_path)
     return
 
 
